@@ -73,3 +73,16 @@ ctxpand<-function(text){
   return(text)
 }
 
+
+#' UK to US conversion
+#' @description background function to load.
+#' @param text character Vector of strings to convert to US spelling.
+#' @return character Vector of Americanized strings.
+#' @keywords internal
+usWords<-function(text){
+  toks <- quanteda::tokens(text)
+  tokUS<-quanteda::tokens_lookup(toks, politeness::uk2us,
+                                 exclusive = FALSE,capkeys = FALSE)
+  sentUS<-unlist(lapply(tokUS,paste, collapse=" "),use.names = F)
+}
+
